@echo off
mode 80,500
setlocal
title Install LdbCard Cassette into Payment Manager

rem ************************************************************************
rem * This source code is provided as an example.  No warranty is expressed
rem * or implied.  It is your responsibility to determine its suitability
rem * to your application, to modify it as necessary, and to validate
rem * its correctness.
rem *
rem * Licensed Materials - Property of IBM
rem * (c) Copyright IBM Corporation 2000. All Rights Reserved.
rem *
rem * US Government Users Restricted Rights - Use, duplication, or
rem * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
rem ************************************************************************

rem ############################################################################
rem #
rem # This script installs the LdbCard cassette into the IBM Payment Manager
rem #
rem # If a preinstall database backup has never been captured, a backup is
rem # captured so the database can be restored to this state (see
rem # LdbCard#RestorePreInstall). Then it will connected to the database,
rem # insert the required row into the ETCASSETTECFG table, create the
rem # cassette tables and views, and finally capture the database so it
rem # can be restored to this pristine state while testing
rem # (see LdbCard#RestorePostInstall).
rem #
rem ############################################################################

rem Set IBM Payment Manager drive, directory name, and database instance
set PAYDRV=c:
set PAYDIR=c:\Program Files\IBM\PaymentManager
set PAYDBI=PSADMIN
%PAYDRV%
cd %PAYDIR%

rem Set the directory where the cassette files can be found
set SRCDIR=D:\!PMCassette\com\ibm\etill\ldbcardcassette

rem Copy cassette files into the production Payment Manager directories.
xcopy %SRCDIR%\*.cmd   "%PAYDIR%"          /F /I
xcopy %SRCDIR%\*.sql   "%PAYDIR%\Archive"  /F /I
xcopy %SRCDIR%\*.PSPL  "%PAYDIR%\pspl"     /F /I
xcopy %SRCDIR%\lib\*.* "%PAYDIR%"          /F /I


rem Save the pre-install database
if exist %PAYDRV%\LdbCard\PreInstallBackup  goto :SkipSave
   mkdir %PAYDRV%\LdbCard\PreInstallBackup
   db2 BACKUP DATABASE %PAYDBI% TO %PAYDRV%\LdbCard\PreInstallBackup
:SkipSave

rem Connect to the database
db2 CONNECT TO %PAYDBI%

rem Insert row in ETCASSETTECFG table and create cassette tables and views
db2 -tvf .\archive\LdbCard.Install.sql

rem Save the post-install database so it can be refreshed during test.
if exist %PAYDRV%\LdbCard\PostInstallBackup rmdir %PAYDRV%\LdbCard\PostInstallBackup /s /q
mkdir %PAYDRV%\LdbCard\PostInstallBackup
db2 BACKUP DATABASE %PAYDBI% TO %PAYDRV%\LdbCard\PostInstallBackup

pause
endlocal
exit
